summaryrefslogtreecommitdiffstats
path: root/client/boot-tools
diff options
context:
space:
mode:
authorramon <ramongomez@us.es>2016-05-03 11:40:20 +0000
committerramon <ramongomez@us.es>2016-05-03 11:40:20 +0000
commit16fc7ab3dc49310205c396d6626a8efd6bff3154 (patch)
tree107458f1c6ebb54a65898c33743eb1a7bae4bf1b /client/boot-tools
parentf932a1aff2f94012908252aa8e484d47b2d4c72d (diff)
#724: Generación de ogLive: limpiar código antiguo, eliminar ficheros no usados, usar nuevo nombre del proyecto e incluir número de revisión.
git-svn-id: https://opengnsys.es/svn/branches/version1.1@4916 a21b9725-9963-47de-94b9-378ad31fedc9
Diffstat (limited to 'client/boot-tools')
-rwxr-xr-xclient/boot-tools/boottoolsfunctions.lib5
-rwxr-xr-xclient/boot-tools/boottoolsgenerator.sh12
-rw-r--r--client/boot-tools/includes/etc/initramfs-tools/scripts/ogfunctions2
-rwxr-xr-xclient/boot-tools/includes/usr/bin/boot-tools/boottoolsFsOpengnsys.sh9
-rwxr-xr-xclient/boot-tools/includes/usr/bin/boot-tools/boottoolsSoftwareCompile.sh27
-rw-r--r--client/boot-tools/includes/var/cache/apt/archivesOG/busybox-static_1.17.1-10ubuntu1_i386.debbin747212 -> 0 bytes
-rw-r--r--client/boot-tools/includes/var/cache/apt/archivesOG/busybox_1.17.1-10ubuntu1_i386.debbin290464 -> 0 bytes
-rw-r--r--client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.38_i386.debbin6319500 -> 0 bytes
-rwxr-xr-xclient/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.7-1drbl_i386.debbin5023908 -> 0 bytes
-rwxr-xr-xclient/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.8_i386.debbin5025002 -> 0 bytes
-rw-r--r--client/boot-tools/includes/var/cache/apt/archivesOG/xvesa.debbin541364 -> 0 bytes
11 files changed, 11 insertions, 44 deletions
diff --git a/client/boot-tools/boottoolsfunctions.lib b/client/boot-tools/boottoolsfunctions.lib
index 02835885..ee29e554 100755
--- a/client/boot-tools/boottoolsfunctions.lib
+++ b/client/boot-tools/boottoolsfunctions.lib
@@ -4,7 +4,7 @@
#@brief Librería o clase Boot-Tools
#@class Boot-Tools
#@brief Funciones para generar un sistema operativo cliente para opengnsys
-#@version 1.0.5
+#@version 1.1.0
#@warning License: GNU GPLv3+
#*/
@@ -93,7 +93,7 @@ case "${1,,}" in
wily) # ogLive 1.1.0-rc1 basado en Ubuntu 15.10.
OSDISTRIB="ubuntu"
OSCODENAME="wily"
- OSRELEASE="4.2.0-16-generic"
+ OSRELEASE="4.2.0-35-generic"
OSARCH="i386"
OSHTTP="http://es.archive.ubuntu.com/ubuntu/"
;;
@@ -113,7 +113,6 @@ NAMEHOSTCLIENT="$VERSIONBOOTTOOLS-$OSCODENAME-$VERSIONSVN"
export OSDISTRIB OSCODENAME OSRELEASE OSARCH OSHTTP
export TYPECLIENT VERSIONSVN NAMEISOCLIENT NAMEHOSTCLIENT
### El fichero de configuración debe sustituir a estos 3 ficheros (borrar las 3 líneas siguientes).
-echo "$VERSIONSVN" > /tmp/versionsvn.txt
echo "$NAMEISOCLIENT" > /tmp/opengnsys_info_rootfs
echo "$NAMEHOSTCLIENT" > /tmp/opengnsys_chroot
# Generar fichero de configuración.
diff --git a/client/boot-tools/includes/etc/initramfs-tools/scripts/ogfunctions b/client/boot-tools/includes/etc/initramfs-tools/scripts/ogfunctions
index 38ed4a06..d70119d3 100644
--- a/client/boot-tools/includes/etc/initramfs-tools/scripts/ogfunctions
+++ b/client/boot-tools/includes/etc/initramfs-tools/scripts/ogfunctions
@@ -1,6 +1,6 @@
#/**
#@file ogfunctions.lib
-#@brief Librería o clase para la gestion del sistema operativo de los clientes OpenGnSys.
+#@brief Librería o clase para la gestion del sistema operativo de los clientes OpenGnsys.
#@class client
#@version 1.1.0
#@warning License: GNU GPLv3+
diff --git a/client/boot-tools/includes/usr/bin/boot-tools/boottoolsFsOpengnsys.sh b/client/boot-tools/includes/usr/bin/boot-tools/boottoolsFsOpengnsys.sh
index f162c82f..b90cf9a1 100755
--- a/client/boot-tools/includes/usr/bin/boot-tools/boottoolsFsOpengnsys.sh
+++ b/client/boot-tools/includes/usr/bin/boot-tools/boottoolsFsOpengnsys.sh
@@ -1,14 +1,5 @@
#!/bin/bash
-#TODO Comprobar si esta los source.
-#svn checkout http://www.opengnsys.es/svn/branches/version1.0/client /tmp/opengnsys_installer/opengnsys/client/;
-#svn checkout http://www.opengnsys.es/svn/branches/version2/ /tmp/opengnsys_installer/opengnsys2
-#find /tmp/opengnsys_installer/ -name .svn -type d -exec rm -fr {} \; 2>/dev/null;
-#apt-get -y --force-yes install subversion
-#export SVNURL="http://opengnsys.es/svn/branches/version1.0/client/"
-#VERSIONSVN=$(LANG=C svn info $SVNURL | awk '/Revision:/ {print "r"$2}')
-
-#VERSIONSVN=$(cat /tmp/versionsvn.txt)
VERSIONBOOTTOOLS="ogLive"
NAMEISOCLIENTFILE="/tmp/opengnsys_info_rootfs"
diff --git a/client/boot-tools/includes/usr/bin/boot-tools/boottoolsSoftwareCompile.sh b/client/boot-tools/includes/usr/bin/boot-tools/boottoolsSoftwareCompile.sh
index 637d2a66..bec4c7c0 100755
--- a/client/boot-tools/includes/usr/bin/boot-tools/boottoolsSoftwareCompile.sh
+++ b/client/boot-tools/includes/usr/bin/boot-tools/boottoolsSoftwareCompile.sh
@@ -26,36 +26,11 @@ which ms-sys || ms-sys install &>/dev/null
echo "spartlnx"
which spartlnx.run || $(wget http://damien.guibouret.free.fr/savepart.zip &>/dev/null; unzip -o savepart.zip -d /sbin/)
-#echo "xvesa"
-gdebi -n /var/cache/apt/archivesOG/xvesa.deb
-
-#echo "partclone"
-#gdebi -n /var/cache/apt/archivesOG/partclone_0.2.38_i386.deb
-
-#echo "comenzamos con el busybox"
-#echo "busybox-static 1.17.1 en rootfs"
-apt-get remove -y busybox-static
-gdebi -n /var/cache/apt/archivesOG/busybox-static_1.17.1-10ubuntu1_i386.deb
-cp /bin/busybox /bin/busyboxOLD
-/bin/busyboxOLD
-echo "busybox-static 1.18.5 en initrd"
+echo "busybox"
apt-get install -y busybox-static
cp /bin/busybox /bin/busyboxNEW
/bin/busyboxNEW
-echo " en scripts reboot y poweroff hacer llamada a busyboxOLD reboot|poweroff "
-
-#gpt
-#echo "gptfdisk"
-#apt-get install -y uuid-dev libicu-dev libpopt-dev libpopt0 ncurses-base libncurses5-dev
-#wget -O download.tgz http://sourceforge.net/projects/gptfdisk/files/gptfdisk/0.8.5/gptfdisk-0.8.5.tar.gz/download -O gptfdisk-0.8.5.tar.gz
-#tar xzvf gptfdisk-0.8.5.tar.gz
-#cd gptfdisk-0.8.5
-#make
-#cp -va sgdisk gdisk fixparts cgdisk /sbin
-#cd ..
-#rm -fr gptfdisk-0.8.5*
-
# Mach-O loader for Linux
echo "maloader"
wget https://github.com/shinh/maloader/archive/master.zip
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/busybox-static_1.17.1-10ubuntu1_i386.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/busybox-static_1.17.1-10ubuntu1_i386.deb
deleted file mode 100644
index c72adfba..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/busybox-static_1.17.1-10ubuntu1_i386.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/busybox_1.17.1-10ubuntu1_i386.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/busybox_1.17.1-10ubuntu1_i386.deb
deleted file mode 100644
index 53679b05..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/busybox_1.17.1-10ubuntu1_i386.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.38_i386.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.38_i386.deb
deleted file mode 100644
index 6159c766..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.38_i386.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.7-1drbl_i386.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.7-1drbl_i386.deb
deleted file mode 100755
index 870b021f..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.7-1drbl_i386.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.8_i386.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.8_i386.deb
deleted file mode 100755
index 9dbe2e9e..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/partclone_0.2.8_i386.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/includes/var/cache/apt/archivesOG/xvesa.deb b/client/boot-tools/includes/var/cache/apt/archivesOG/xvesa.deb
deleted file mode 100644
index 72433e76..00000000
--- a/client/boot-tools/includes/var/cache/apt/archivesOG/xvesa.deb
+++ /dev/null
Binary files differ
diff --git a/client/boot-tools/boottoolsgenerator.sh b/client/boot-tools/boottoolsgenerator.sh
index c6738e26..e6750f04 100755
--- a/client/boot-tools/boottoolsgenerator.sh
+++ b/client/boot-tools/boottoolsgenerator.sh
@@ -1,6 +1,6 @@
#!/bin/bash
#@file boottoolsgenerator.sh
#@brief Script generación del sistema opertativo cliente OpenGnSys
#@warning
#@version 0.9 - Prototipo de sistema operativo multiarranque de opengnsys.
#@author Antonio J. Doblas Viso. Universidad de Malaga.
@@ -11,7 +11,7 @@
#*/
#mkdir -p /tmp/opengnsys_installer/opengnsys
- #svn export http://opengnsys.es/svn/branches/version1.0/client /tmp/opengnsys_installer/opengnsys
+ #svn export http://opengnsys.es/svn/branches/version1.1/client /tmp/opengnsys_installer/opengnsys
#Variables
@@ -42,7 +42,7 @@ source $PROGRAMDIR/boottoolsfunctions.lib
echo "FASE 1 - Asignación de variables"
#obtenemos las variables necesarias y la información del host.
btogGetVar
-echoAndLog "OpenGnSys CLIENT installation begins at $(date)"
+echoAndLog "OpenGnsys CLIENT installation begins at $(date)"
btogGetOsInfo $TYPECLIENT
##########################################################################
echo "FASE 2 - Instalación de software adicional."
@@ -68,9 +68,11 @@ fi
echo "FASE 4 - Configurar acceso schroot al Segundo Sistema de archivos (img)"
cat /etc/schroot/schroot.conf | grep $BTROOTFSIMG || btogSetFsAccess
###########################################################################
-echo "FASE 5 - Incorporando ficheros OpenGnSys el sistema raiz rootfs "
+echo "FASE 5 - Incorporando ficheros OpenGnsys al sistema raíz rootfs "
cp -a ${BTSVNBOOTTOOLS}/includes/usr/bin/* /tmp
chmod +x /tmp/boot-tools/*.sh
+# Incluir revisión.
+sed -i "1 s/$/ $VERSIONSVN/" ${BTSVNBOOTTOOLS}/includes/etc/initramfs-tools/scripts/VERSION.txt
# En Ubuntu 13.04+ es necesario matar proceso de "udev" antes de desmontar.
umount $BTROOTFSMNT 2>/dev/null || (kill -9 $(lsof -t $BTROOTFSMNT); umount $BTROOTFSMNT 2>/dev/null)
schroot -p -c IMGogclient -- /tmp/boot-tools/boottoolsFsOpengnsys.sh
@@ -112,5 +114,5 @@ echo "Fase 8.3 Generar la ISO"
btogIsoGenerator
######################################################################3
########################################################################
-echoAndLog "OpenGnSys installation finished at $(date)"
+echoAndLog "OpenGnsys installation finished at $(date)"
@@ -1,6 +1,6 @@
#!/bin/bash
#@file boottoolsgenerator.sh
-#@brief Script generación del sistema opertativo cliente OpenGnSys
+#@brief Script generación del sistema opertativo cliente OpenGnsys
#@warning
#@version 0.9 - Prototipo de sistema operativo multiarranque de opengnsys.